@@ -23,7 +23,7 @@ class Message:
         self.attachments = attachments
         self.embeds = emebds
         self.mentions = mentions
-        self. mention_roles = mention_roles
+        self.mention_roles = mention_roles
         self.pinned = pinned
         self.tts = tts
         self.timestamp = timestamp
@@ -46,28 +46,18 @@ class DisWrapper:
         return res
 
     def auth(self, email, password):
-        if os.path.isfile("auth.cache"):
-            with open("auth.cache", "r") as auth_file:
-                json_content = json.load(auth_file)
-                self.theme = json_content["theme"]
-                self.locale = json_content["locale"]
-                self.token = json_content["auth"]
-        else:
-            header = {
-                "content-type": "application/json"
-            }
-            payload = {"email": email, "password": password}
-            url = "https://discord.com/api/v6/auth/login"
+        header = {
+            "content-type": "application/json"
+        }
+        payload = {"email": email, "password": password}
+        url = "https://discord.com/api/v6/auth/login"
 
-            req = self.sendReq("POST", url, payload, header).text
-            json_request = json.loads(req)
+        req = self.sendReq("POST", url, payload, header).text
+        json_request = json.loads(req)
 
-            self.theme = json_request["user_settings"]["theme"]
-            self.locale = json_request["user_settings"]["locale"]
-            self.token = json_request["token"]
-
-            with open("auth.cache", "w") as auth_file:
-                json.dump({"auth": self.token, "theme": self.theme, "locale": self.locale}, auth_file)
+        self.theme = json_request["user_settings"]["theme"]
+        self.locale = json_request["user_settings"]["locale"]
+        self.token = json_request["token"]
         return self.token
 
 
@@ -163,7 +153,17 @@ class DisWrapper:
                         req_json["user"]["discriminator"], req_json["user"]["public_flags"], req_json["nick"])
         
         return new_user
-        
+    
+    def getUserInfo(self, user_id):
+        headers = {"Authorization": self.token}
+        url = f"https://discordapp.com/api/v6/users/{user_id}"
+
+        req = self.sendReq("GET", url, headers=headers)
+        req_json = json.loads(req.text)
+
+        new_user = User(req_json["id"], req_json["username"], req_json["avatar"], 
+                        req_json["discriminator"], req_json["public_flags"])
+        return new_user
 
     def get_websocket_gateway(self):
         req = self.sendReq("GET", "https://discordapp.com/api/v6/auth/login")
